Tutorials
=========

The best way to learn OGGM is to run our tutorials, available
in the form of Jupyter Notebooks.

You will find them online at: `https://oggm.org/tutorials <https://oggm.org/tutorials>`_

To launch an interactive session on MyBinder and run the tutorials without
having to install anything, visit :doc:`cloud`!
